diff --git a/temp/declarations/cc.d.ts b/temp/declarations/cc.d.ts
index 5109921..6d527cb 100644
--- a/temp/declarations/cc.d.ts
+++ b/temp/declarations/cc.d.ts
@@ -1,5 +1,5 @@
- ///
+ ///
/**
* @deprecated Global variable `cc` was dropped since 3.0. Use ES6 module syntax to import Cocos Creator APIs.
diff --git a/temp/declarations/jsb.d.ts b/temp/declarations/jsb.d.ts
index eb5898b..19ce77a 100644
--- a/temp/declarations/jsb.d.ts
+++ b/temp/declarations/jsb.d.ts
@@ -1 +1 @@
-///
+///
diff --git a/tsconfig.json b/tsconfig.json
index 2eb8d5c..af618d9 100644
--- a/tsconfig.json
+++ b/tsconfig.json
@@ -3,7 +3,7 @@
"target": "ES2017",
"module": "CommonJS",
"outDir": "./dist",
- "rootDir": "./src",
+ "rootDir": "./",
"strict": true,
"moduleResolution": "node",
"esModuleInterop": true,
@@ -19,7 +19,14 @@
"./temp/declarations/cc.env"
]
},
+ "include": [
+ "assets/**/*",
+ "src/**/*",
+ "typedoc.ts"
+ ],
"exclude": [
- "assets/**/*"
+ "node_modules",
+ "dist",
+ "temp"
]
}
\ No newline at end of file
diff --git a/temp/declarations/cc.env.d.ts b/temp/declarations/cc.env.d.ts
index e604bb0..7e93b00 100644
--- a/temp/declarations/cc.env.d.ts
+++ b/temp/declarations/cc.env.d.ts
@@ -54,11 +54,6 @@ declare module 'cc/env'{
*/
export const WECHAT_MINI_PROGRAM: boolean;
- /**
- * Running in the baidu's mini game.
- */
- export const BAIDU: boolean;
-
/**
* Running in the xiaomi's quick game.
*/
@@ -100,19 +95,19 @@ declare module 'cc/env'{
export const HUAWEI: boolean;
/**
- * Running in the cocosplay.
+ * Running in the migu's quick game.
*/
- export const COCOSPLAY: boolean;
+ export const MIGU: boolean;
/**
* Running in the qtt's quick game.
*/
- export const QTT: boolean;
+ export const HONOR: boolean;
/**
- * Running in the linksure's quick game.
+ * Running in the cocos runtime.
*/
- export const LINKSURE: boolean;
+ export const COCOS_RUNTIME: boolean;
/**
* Running in the editor.
@@ -100,19 +95,19 @@ declare module 'cc/env'{
/**
- * Running in the qtt's quick game.
+ * Running in the honor's quick game.
*/